/**
 * File name: VstIds.h
 * Project: Geonkick (A kick synthesizer)
 *
 * Copyright (C) 2019 Iurie Nistor 
 *
 * This file is part of Geonkick.
 *
 * GeonKick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GEONKICK_VST_IDS_H
#define GEONKICK_VST_IDS_H

#include "globals.h"

#include "pluginterfaces/base/funknown.h"

//#include <RkLog.h>

using namespace Steinberg;
static const FUID GKickVstProcessorUID(0xE2CC9532, 0x90E863F0, 0x6405E139, 0x24E34B24);

#endif // GEONKICK_VST_IDS_H
